@@ -19,7 +19,7 @@
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "powerpc-unknown-netbsd9.0"
+#define LLVM_DEFAULT_TARGET_TRIPLE "mips64eb-unknown-netbsd10.0"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,28 +28,28 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "powerpc-unknown-netbsd9.0"
+#define LLVM_HOST_TRIPLE "mips64eb-unknown-netbsd10.0"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH PowerPC
+#define LLVM_NATIVE_ARCH Mips
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializePowerPCAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializePowerPCAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializePowerPCDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializePowerPCTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializePowerPCTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializePowerPCTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
 
 /* LLVM name for the native target MCA init function, if available */
 /* #undef LLVM_NATIVE_TARGETMCA */
@@ -67,7 +67,7 @@
 #define LLVM_USE_PERF 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 16
+#define LLVM_VERSION_MAJOR 17
 
 /* Minor version of the LLVM API */
 #define LLVM_VERSION_MINOR 0
@@ -76,7 +76,7 @@
 #define LLVM_VERSION_PATCH 6
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "16.0.6"
+#define LLVM_VERSION_STRING "17.0.6"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
